##############################################################################
#  Script: Update-ComputerDescription.ps1
#    Date: 7.Jun.2007
# Version: 1.0
#  Author: Jason Fossen (www.WindowsPowerShellTraining.com)
# Purpose: Adds the OS version and Service Pack number to the description 
#          field on all computers in the target AD container.  Target container
#          can be the entire domain (the default) or the name (or full DN path)
#          to a particular OU or Container in AD.  Computer accounts that exist
#          but which have never been used are updated as well with a note to
#          that effect.  
#   Legal: Script provided "AS IS" without warranties or guarantees of any
#          kind.  USE AT YOUR OWN RISK.  Public domain, no rights reserved.
##############################################################################




param ($DomainController = 'localhost', $Container = $null)


function Update-ComputerDescription ($DomainController = 'localhost', $Container = $null)
{
    $con = connect-qadservice -service $DomainController
    
    switch ($Container)
    {
        {$Container -eq $null} 
            { 
                $path = $con.DN
                break 
            }
        {$Container -match $con.DN}  # Assume full DN path has been supplied.
            { 
                $path = (get-qadobject -Identity "$Container").DN 
                if ($path -eq $null) { throw "DN path resolution failed, please check the path!" ; return } 
            }
        default   # Assume just the OU or container name was supplied, not its full DN.
            {
                $path = ( get-qadobject -SearchRoot $con.DN -Name "$Container" | select-object DN )
            
                if ($path.length -eq $null)  # It's not an array, it has only one item.
                 { $path = $path.DN }  
                else
                 { throw "The name is ambiguous, please enter full DN path!" ; return }
            }
    } 
    
    
    #get-qadcomputer -SearchRoot $path -SizeLimit 100000 -LdapFilter "(!(description=*))" |  # Updates blank descriptions only.
    get-qadcomputer -SearchRoot $path -SizeLimit 100000 |
    foreach-object { 
        if ( $($_.OSName) -eq $null )
         { set-qadobject -identity "$_" -objectattributes @{description="Never Connected (Created $($_.CreationDate))"} }
        else
         { set-qadobject -identity "$_" -objectattributes @{description="$($_.OSName) $($_.OSServicePack)"} }
    } 

    disconnect-qadservice 
}



Update-ComputerDescription -domaincontroller $DomainController -container $Container



